==> qtjambi-qml-debuginfo-macos-6.8.1.jar: sources/QtJambiQml/QQmlNetworkAccessManagerFactory_shell.cpp <==
#include "QQmlNetworkAccessManagerFactory_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlNetworkAccessManagerFactory(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlNetworkAccessManagerFactory")
    QQmlNetworkAccessManagerFactory *_ptr = reinterpret_cast<QQmlNetworkAccessManagerFactory *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlNetworkAccessManagerFactory_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlNetworkAccessManagerFactory_shell) ); }

jmethodID QQmlNetworkAccessManagerFactory_oshell::__shell_javaMethod(int pos) const { return QQmlNetworkAccessManagerFactory_shell::__shell()->javaMethod(typeid(QQmlNetworkAccessManagerFactory), pos); }

// emitting (writeShellDestructor)
QQmlNetworkAccessManagerFactory_shell::~QQmlNetworkAccessManagerFactory_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlNetworkAccessManagerFactory::~QQmlNetworkAccessManagerFactory()", this)
    QQmlNetworkAccessManagerFactory_shell::__shell()->destructed(typeid(QQmlNetworkAccessManagerFactory));
}

// emitting (writeShellConstructor)
QQmlNetworkAccessManagerFactory_shell::QQmlNetworkAccessManagerFactory_shell()
    : QQmlNetworkAccessManagerFactory()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlNetworkAccessManagerFactory::QQmlNetworkAccessManagerFactory_shell()", this)
    QQmlNetworkAccessManagerFactory_shell::__shell()->constructed(typeid(QQmlNetworkAccessManagerFactory));
}

void QQmlNetworkAccessManagerFactory_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlNetworkAccessManagerFactory_oshell*>(ptr)->QQmlNetworkAccessManagerFactory_oshell::__shell()->tryDeleteShell(typeid(QQmlNetworkAccessManagerFactory));
}

// emitting Virtual overrides (virtualFunctions)
QNetworkAccessManager* QQmlNetworkAccessManagerFactory_oshell::create(QObject* parent0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlNetworkAccessManagerFactory::create(QObject*)", this)
        if (JniEnvironmentExceptionHandler __jni_env{300}) {
            QNetworkAccessManager*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlNetworkAccessManagerFactory_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_parent0 = qtjambi_cast<jobject>(__jni_env, parent0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_parent0);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_parent0);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = qtjambi_cast<QNetworkAccessManager*>(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnershipForTopLevelObject(__jni_env, __qt_return_value);
                } else {
                    QQmlNetworkAccessManagerFactory_shell::__shell()->warnForMethod("QQmlNetworkAccessManagerFactory::create(QObject*)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QQmlNetworkAccessManagerFactory::create(QObject*)");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return nullptr;
        }
    }else{
        return nullptr;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QQmlNetworkAccessManagerFactory_access::__qt_create_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QObject* __qt_parent0 = QtJambiAPI::objectFromNativeId<QObject>(parent0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlNetworkAccessManagerFactory::create(QObject * parent)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlNetworkAccessManagerFactory::create(QObject * parent).";
    } else {
        QNetworkAccessManager* __qt_return_value = create(__qt_parent0);
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QQmlNetworkAccessManagerFactory()
void __qt_construct_QQmlNetworkAccessManagerFactory(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlNetworkAccessManagerFactory()")
    Q_UNUSED(__java_arguments)
    QQmlNetworkAccessManagerFactory *__qt_this = new(__qtjambi_ptr) QQmlNetworkAccessManagerFactory_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QQmlNetworkAccessManagerFactory::QQmlNetworkAccessManagerFactory()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlNetworkAccessManagerFactory_00024Impl_initialize_1native__Lio_qt_qml_QQmlNetworkAccessManagerFactory_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlNetworkAccessManagerFactory::QQmlNetworkAccessManagerFactory()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlNetworkAccessManagerFactory, sizeof(QQmlNetworkAccessManagerFactory_shell), typeid(QQmlNetworkAccessManagerFactory), 0, true, &deleter_QQmlNetworkAccessManagerFactory, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlNetworkAccessManagerFactory_shell
void __qt_destruct_QQmlNetworkAccessManagerFactory(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlNetworkAccessManagerFactory")
    reinterpret_cast<QQmlNetworkAccessManagerFactory_shell*>(ptr)->~QQmlNetworkAccessManagerFactory_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlNetworkAccessManagerFactory::create(QObject*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlNetworkAccessManagerFactory_00024Impl_00024ConcreteWrapper_create_1native_1QObject_1ptr__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID parent0)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QQmlNetworkAccessManagerFactory *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlNetworkAccessManagerFactory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlNetworkAccessManagerFactory::create(QObject*)", __this_nativeId)
        __java_return_value = static_cast<QQmlNetworkAccessManagerFactory_access*>(__qt_this)->__qt_create_QObject_ptr(__jni_env, __this_nativeId, parent0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlNetworkAccessManagerFactory(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlNetworkAccessManagerFactory>("QQmlNetworkAccessManagerFactory", "io/qt/qml/QQmlNetworkAccessManagerFactory");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo{/* 0 */ "create", "(Lio/qt/core/QObject;)Lio/qt/network/QNetworkAccessManager;", FunctionInfo::Abstract}});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlNetworkAccessManagerFactory, {
        ConstructorInfo{&__qt_construct_QQmlNetworkAccessManagerFactory, nullptr}
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlNetworkAccessManagerFactory);
    registerSizeOfShell(typeId, sizeof(QQmlNetworkAccessManagerFactory_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlNetworkAccessManagerFactory* _object = dynamic_cast<QQmlNetworkAccessManagerFactory*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlNetworkAccessManagerFactory *object = reinterpret_cast<QQmlNetworkAccessManagerFactory *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlNetworkAccessManagerFactory *object = reinterpret_cast<const QQmlNetworkAccessManagerFactory *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.8.5.jar: sources/QtJambiQml/QQmlNetworkAccessManagerFactory_shell.cpp <==
#include "QQmlNetworkAccessManagerFactory_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlNetworkAccessManagerFactory(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlNetworkAccessManagerFactory")
    QQmlNetworkAccessManagerFactory *_ptr = reinterpret_cast<QQmlNetworkAccessManagerFactory *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlNetworkAccessManagerFactory_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlNetworkAccessManagerFactory_shell) ); }

jmethodID QQmlNetworkAccessManagerFactory_oshell::__shell_javaMethod(int pos) const { return QQmlNetworkAccessManagerFactory_shell::__shell()->javaMethod(typeid(QQmlNetworkAccessManagerFactory), pos); }

// emitting (writeShellDestructor)
QQmlNetworkAccessManagerFactory_shell::~QQmlNetworkAccessManagerFactory_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlNetworkAccessManagerFactory::~QQmlNetworkAccessManagerFactory()", this)
    QQmlNetworkAccessManagerFactory_shell::__shell()->destructed(typeid(QQmlNetworkAccessManagerFactory));
}

// emitting (writeShellConstructor)
QQmlNetworkAccessManagerFactory_shell::QQmlNetworkAccessManagerFactory_shell()
    : QQmlNetworkAccessManagerFactory()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlNetworkAccessManagerFactory::QQmlNetworkAccessManagerFactory_shell()", this)
    QQmlNetworkAccessManagerFactory_shell::__shell()->constructed(typeid(QQmlNetworkAccessManagerFactory));
}

void QQmlNetworkAccessManagerFactory_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlNetworkAccessManagerFactory_oshell*>(ptr)->QQmlNetworkAccessManagerFactory_oshell::__shell()->tryDeleteShell(typeid(QQmlNetworkAccessManagerFactory));
}

// emitting Virtual overrides (virtualFunctions)
QNetworkAccessManager* QQmlNetworkAccessManagerFactory_oshell::create(QObject* parent0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlNetworkAccessManagerFactory::create(QObject*)", this)
        if (JniEnvironmentExceptionHandler __jni_env{300}) {
            QNetworkAccessManager*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlNetworkAccessManagerFactory_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_parent0 = qtjambi_cast<jobject>(__jni_env, parent0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_parent0);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_parent0);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = qtjambi_cast<QNetworkAccessManager*>(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnershipForTopLevelObject(__jni_env, __qt_return_value);
                } else {
                    QQmlNetworkAccessManagerFactory_shell::__shell()->warnForMethod("QQmlNetworkAccessManagerFactory::create(QObject*)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, this, "QQmlNetworkAccessManagerFactory::create(QObject*)");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return nullptr;
        }
    }else{
        return nullptr;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QQmlNetworkAccessManagerFactory_access::__qt_create_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QObject* __qt_parent0 = QtJambiAPI::objectFromNativeId<QObject>(parent0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlNetworkAccessManagerFactory::create(QObject * parent)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlNetworkAccessManagerFactory::create(QObject * parent).";
    } else {
        QNetworkAccessManager* __qt_return_value = create(__qt_parent0);
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QQmlNetworkAccessManagerFactory()
void __qt_construct_QQmlNetworkAccessManagerFactory(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlNetworkAccessManagerFactory()")
    Q_UNUSED(__java_arguments)
    QQmlNetworkAccessManagerFactory *__qt_this = new(__qtjambi_ptr) QQmlNetworkAccessManagerFactory_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QQmlNetworkAccessManagerFactory::QQmlNetworkAccessManagerFactory()
extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QQmlNetworkAccessManagerFactory_00024Impl_initialize_1native__Lio_qt_qml_QQmlNetworkAccessManagerFactory_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlNetworkAccessManagerFactory::QQmlNetworkAccessManagerFactory()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlNetworkAccessManagerFactory, sizeof(QQmlNetworkAccessManagerFactory_shell), typeid(QQmlNetworkAccessManagerFactory), 0, true, &deleter_QQmlNetworkAccessManagerFactory, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlNetworkAccessManagerFactory_shell
void __qt_destruct_QQmlNetworkAccessManagerFactory(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlNetworkAccessManagerFactory")
    reinterpret_cast<QQmlNetworkAccessManagerFactory_shell*>(ptr)->~QQmlNetworkAccessManagerFactory_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlNetworkAccessManagerFactory::create(QObject*)
extern "C" JNIEXPORT jobject JNICALL Java_io_qt_qml_QQmlNetworkAccessManagerFactory_00024Impl_00024ConcreteWrapper_create_1native_1QObject_1ptr__JJ
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID parent0)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QQmlNetworkAccessManagerFactory *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlNetworkAccessManagerFactory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlNetworkAccessManagerFactory::create(QObject*)", __this_nativeId)
        __java_return_value = static_cast<QQmlNetworkAccessManagerFactory_access*>(__qt_this)->__qt_create_QObject_ptr(__jni_env, __this_nativeId, parent0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlNetworkAccessManagerFactory(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlNetworkAccessManagerFactory>("QQmlNetworkAccessManagerFactory", "io/qt/qml/QQmlNetworkAccessManagerFactory");
    registerFunctionInfos(typeId, {
        FunctionInfo{/* 0 */ "create", "(Lio/qt/core/QObject;)Lio/qt/network/QNetworkAccessManager;", FunctionInfo::Abstract}});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlNetworkAccessManagerFactory, {
        ConstructorInfo{&__qt_construct_QQmlNetworkAccessManagerFactory, nullptr}
    });
    registerDeleter(typeId, &deleter_QQmlNetworkAccessManagerFactory);
    registerSizeOfShell(typeId, sizeof(QQmlNetworkAccessManagerFactory_shell));
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlNetworkAccessManagerFactory* _object = dynamic_cast<QQmlNetworkAccessManagerFactory*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlNetworkAccessManagerFactory *object = reinterpret_cast<QQmlNetworkAccessManagerFactory *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlNetworkAccessManagerFactory *object = reinterpret_cast<const QQmlNetworkAccessManagerFactory *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
}
